@@ -13,5 +13,5 @@ def register(linter):
     linter.register_checker(SelectCastChecker(linter))
     linter.register_checker(StatementCallChecker(linter))
     linter.register_checker(ConfluencePageChecker(linter))
-    # linter.register_checker(ChainedDotFunctionsSyntaxChecker(linter))
+    linter.register_checker(ChainedDotFunctionsSyntaxChecker(linter))
 
